@@ -1,10 +1,9 @@
 package MARC::Moose::Record;
 {
-  $MARC::Moose::Record::VERSION = '0.020';
+  $MARC::Moose::Record::VERSION = '0.021';
 }
 # ABSTRACT: MARC::Moose bibliographic record
 
-use namespace::autoclean;
 use Moose;
 
 use Carp;
@@ -57,6 +56,12 @@ my $parser = {
 };
 
 
+{
+    $MARC::Moose::Record::formater = $formater;
+    $MARC::Moose::Record::parser = $parser;
+}
+
+
 sub set_leader_length {
     my ($self, $length, $offset) = @_;
 
@@ -177,7 +182,7 @@ MARC::Moose::Record - MARC::Moose bibliographic record
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 DESCRIPTION
 
